@@ -33,14 +33,6 @@
 #define ENUM_ID         10
 
 
-static void apiEnums(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp);
-static void apiVars(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp);
-static void apiCtor(sipSpec *pt, moduleDef *mod, classDef *scope, ctorDef *ct,
-        FILE *fp);
-static void apiOverload(sipSpec *pt, moduleDef *mod, classDef *scope,
-        overDef *od, FILE *fp);
-static int apiArgument(sipSpec *pt, argDef *ad, int out, int need_comma,
-        int names, int defaults, int in_str, FILE *fp);
 static void xmlClass(sipSpec *pt, moduleDef *mod, classDef *cd, FILE *fp);
 static void xmlEnums(sipSpec *pt, moduleDef *mod, classDef *scope, int indent,
         FILE *fp);
@@ -62,8 +54,6 @@ static void xmlIndent(int indent, FILE *fp);
 static void xmlRealName(scopedNameDef *fqcname, const char *member, FILE *fp);
 static void xmlRealScopedName(classDef *scope, const char *cppname, FILE *fp);
 static const char *pyType(sipSpec *pt, argDef *ad, classDef **scope);
-static void exportPythonSignature(sipSpec *pt, FILE *fp, signatureDef *sd,
-        int names, int defaults, int in_str, int is_signal);
 static void restPyEnumMember(enumMemberDef *emd, FILE *fp);
 static void restPyAttribute(moduleDef *mod, classDef *scope, nameDef *name,
         FILE *fp);
@@ -75,225 +65,6 @@ static void freeScopedName(scopedNameDef *snd);
 static scopedNameDef *text2scopePart(char *text);
 
 
-/*
- * Generate the API file.
- */
-int generateAPI(sipSpec *pt, moduleDef *mod, const char *apiFile)
-{
-    overDef *od;
-    classDef *cd;
-    FILE *fp;
-
-    /* Generate the file. */
-    if ((fp = fopen(apiFile, "w")) == NULL)
-        return error("Unable to create file \"%s\"\n", apiFile);
-
-    apiEnums(pt, mod, NULL, fp);
-    apiVars(pt, mod, NULL, fp);
-
-    for (od = mod->overs; od != NULL; od = od->next)
-    {
-        if (od->common->module != mod)
-            continue;
-
-        if (od->common->slot != no_slot)
-            continue;
-
-        apiOverload(pt, mod, NULL, od, fp);
-    }
-
-    for (cd = pt->classes; cd != NULL; cd = cd->next)
-    {
-        ctorDef *ct;
-
-        if (cd->iff->module != mod)
-            continue;
-
-        if (isExternal(cd))
-            continue;
-
-        apiEnums(pt, mod, cd, fp);
-        apiVars(pt, mod, cd, fp);
-
-        for (ct = cd->ctors; ct != NULL; ct = ct->next)
-        {
-            if (isPrivateCtor(ct))
-                continue;
-
-            apiCtor(pt, mod, cd, ct, fp);
-        }
-
-        for (od = cd->overs; od != NULL; od = od->next)
-        {
-            if (isPrivate(od))
-                continue;
-
-            if (od->common->slot != no_slot)
-                continue;
-
-            apiOverload(pt, mod, cd, od, fp);
-        }
-    }
-
-    fclose(fp);
-
-    return 0;
-}
-
-
-/*
- * Generate an API ctor.
- */
-static void apiCtor(sipSpec *pt, moduleDef *mod, classDef *scope, ctorDef *ct,
-        FILE *fp)
-{
-    int need_comma, a;
-
-    /* Do the callable type form. */
-    fprintf(fp, "%s.", mod->name);
-    prScopedPythonName(fp, scope->ecd, scope->pyname->text);
-    fprintf(fp, "?%d(", CLASS_ID);
-
-    need_comma = FALSE;
-
-    for (a = 0; a < ct->pysig.nrArgs; ++a)
-    {
-        argDef *ad = &ct->pysig.args[a];
-
-        need_comma = apiArgument(pt, ad, FALSE, need_comma, TRUE, TRUE, FALSE,
-                fp);
-    }
-
-    fprintf(fp, ")\n");
-
-    /* Do the call __init__ form. */
-    fprintf(fp, "%s.", mod->name);
-    prScopedPythonName(fp, scope->ecd, scope->pyname->text);
-    fprintf(fp, ".__init__?%d(self", CLASS_ID);
-
-    for (a = 0; a < ct->pysig.nrArgs; ++a)
-        apiArgument(pt, &ct->pysig.args[a], FALSE, TRUE, TRUE, TRUE, FALSE,
-                fp);
-
-    fprintf(fp, ")\n");
-}
-
-
-/*
- * Generate the APIs for all the enums in a scope.
- */
-static void apiEnums(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp)
-{
-    enumDef *ed;
-
-    for (ed = pt->enums; ed != NULL; ed = ed->next)
-    {
-        enumMemberDef *emd;
-
-        if (ed->module != mod)
-            continue;
-
-        if (ed->ecd != scope)
-            continue;
-
-        if (ed->pyname != NULL)
-        {
-            fprintf(fp, "%s.", mod->name);
-            prScopedPythonName(fp, ed->ecd, ed->pyname->text);
-            fprintf(fp, "?%d\n", ENUM_ID);
-        }
-
-        for (emd = ed->members; emd != NULL; emd = emd->next)
-        {
-            fprintf(fp, "%s.", mod->name);
-
-            if (ed->pyname != NULL)
-            {
-                prScopedPythonName(fp, ed->ecd, ed->pyname->text);
-                fprintf(fp, ".");
-            }
-
-            fprintf(fp, "%s?%d\n", emd->pyname->text, ENUM_ID);
-        }
-    }
-}
-
-
-/*
- * Generate the APIs for all the variables in a scope.
- */
-static void apiVars(sipSpec *pt, moduleDef *mod, classDef *scope, FILE *fp)
-{
-    varDef *vd;
-
-    for (vd = pt->vars; vd != NULL; vd = vd->next)
-    {
-        if (vd->module != mod)
-            continue;
-
-        if (vd->ecd != scope)
-            continue;
-
-        fprintf(fp, "%s.", mod->name);
-        prScopedPythonName(fp, vd->ecd, vd->pyname->text);
-        fprintf(fp, "?%d\n", VARIABLE_ID);
-    }
-}
-
-
-/*
- * Generate a single API overload.
- */
-static void apiOverload(sipSpec *pt, moduleDef *mod, classDef *scope,
-        overDef *od, FILE *fp)
-{
-    fprintf(fp, "%s.", mod->name);
-    prScopedPythonName(fp, scope, od->common->pyname->text);
-    fprintf(fp, "?%d", METHOD_ID);
-
-    exportPythonSignature(pt, fp, &od->pysig, TRUE, TRUE, FALSE, FALSE);
-
-    fprintf(fp, "\n");
-}
-
-
-/*
- * Generate the API for an argument.
- */
-static int apiArgument(sipSpec *pt, argDef *ad, int out, int need_comma,
-        int names, int defaults, int in_str, FILE *fp)
-{
-    const char *tname;
-    classDef *tscope;
-
-    if (isArraySize(ad))
-        return need_comma;
-
-    if ((tname = pyType(pt, ad, &tscope)) == NULL)
-        return need_comma;
-
-    if (need_comma)
-        fprintf(fp, ", ");
-
-    prScopedPythonName(fp, tscope, tname);
-
-    /*
-     * Handle the default value is required, but ignore it if it is an output
-     * only argument.
-     */
-    if (defaults && ad->defval && !out)
-    {
-        if (names && ad->name != NULL)
-            fprintf(fp, " %s", ad->name->text);
-
-        fprintf(fp, "=");
-        prDefaultValue(ad, in_str, fp);
-    }
-
-    return TRUE;
-}
-
-
 /*
  * Generate the XML export file.
  */
@@ -1127,82 +898,6 @@ static const char *pyType(sipSpec *pt, argDef *ad, classDef **scope)
 }
 
 
-/*
- * Generate a Python signature.
- */
-static void exportPythonSignature(sipSpec *pt, FILE *fp, signatureDef *sd,
-        int names, int defaults, int in_str, int is_signal)
-{
-    int need_comma = FALSE, is_res, nr_out, a;
-
-    if (is_signal)
-    {
-        if (sd->nrArgs != 0)
-            fprintf(fp, "[");
-    }
-    else
-    {
-        fprintf(fp, "(");
-    }
-
-    nr_out = 0;
-
-    for (a = 0; a < sd->nrArgs; ++a)
-    {
-        argDef *ad = &sd->args[a];
-
-        if (isOutArg(ad))
-            ++nr_out;
-
-        if (!isInArg(ad))
-            continue;
-
-        need_comma = apiArgument(pt, ad, FALSE, need_comma, names, defaults,
-                in_str, fp);
-    }
-
-    if (is_signal)
-    {
-        if (sd->nrArgs != 0)
-            fprintf(fp, "]");
-    }
-    else
-    {
-        fprintf(fp, ")");
-    }
-
-
-    is_res = !(sd->result.atype == void_type && sd->result.nrderefs == 0);
-
-    if (is_res || nr_out > 0)
-    {
-        fprintf(fp, " -> ");
-
-        if ((is_res && nr_out > 0) || nr_out > 1)
-            fprintf(fp, "(");
-
-        if (is_res)
-            need_comma = apiArgument(pt, &sd->result, TRUE, FALSE, FALSE,
-                    FALSE, in_str, fp);
-        else
-            need_comma = FALSE;
-
-        for (a = 0; a < sd->nrArgs; ++a)
-        {
-            argDef *ad = &sd->args[a];
-
-            if (isOutArg(ad))
-                /* We don't want the name in the result tuple. */
-                need_comma = apiArgument(pt, ad, TRUE, need_comma, FALSE,
-                        FALSE, in_str, fp);
-        }
-
-        if ((is_res && nr_out > 0) || nr_out > 1)
-            fprintf(fp, ")");
-    }
-}
-
-
 /*
  * Generate a fully qualified attribute name as a reST reference.
  */
